#ifndef NT2_INCLUDE_CONSTANTS_BITINCREMENT_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_BITINCREMENT_HPP_INCLUDED

#include <nt2/constant/include/constants/bitincrement.hpp>

#endif
